@@ -146,6 +146,7 @@ class SerialPipeline(proto.Message):
 
 class Stage(proto.Message):
     r"""Stage specifies a location to which to deploy.
+
     Attributes:
         target_id (str):
             The target_id to which this stage points. This field refers
@@ -224,6 +225,7 @@ class PipelineCondition(proto.Message):
 
 class ListDeliveryPipelinesRequest(proto.Message):
     r"""The request object for ``ListDeliveryPipelines``.
+
     Attributes:
         parent (str):
             Required. The parent, which owns this collection of
@@ -260,6 +262,7 @@ class ListDeliveryPipelinesRequest(proto.Message):
 
 class ListDeliveryPipelinesResponse(proto.Message):
     r"""The response object from ``ListDeliveryPipelines``.
+
     Attributes:
         delivery_pipelines (Sequence[google.cloud.deploy_v1.types.DeliveryPipeline]):
             The ``DeliveryPipeline`` objects.
@@ -284,6 +287,7 @@ class ListDeliveryPipelinesResponse(proto.Message):
 
 class GetDeliveryPipelineRequest(proto.Message):
     r"""The request object for ``GetDeliveryPipeline``
+
     Attributes:
         name (str):
             Required. Name of the ``DeliveryPipeline``. Format must be
@@ -295,6 +299,7 @@ class GetDeliveryPipelineRequest(proto.Message):
 
 class CreateDeliveryPipelineRequest(proto.Message):
     r"""The request object for ``CreateDeliveryPipeline``.
+
     Attributes:
         parent (str):
             Required. The parent collection in which the
@@ -339,6 +344,7 @@ class CreateDeliveryPipelineRequest(proto.Message):
 
 class UpdateDeliveryPipelineRequest(proto.Message):
     r"""The request object for ``UpdateDeliveryPipeline``.
+
     Attributes:
         update_mask (google.protobuf.field_mask_pb2.FieldMask):
             Required. Field mask is used to specify the fields to be
@@ -390,6 +396,7 @@ class UpdateDeliveryPipelineRequest(proto.Message):
 
 class DeleteDeliveryPipelineRequest(proto.Message):
     r"""The request object for ``DeleteDeliveryPipeline``.
+
     Attributes:
         name (str):
             Required. The name of the ``DeliveryPipeline`` to delete.
@@ -547,6 +554,7 @@ class ExecutionConfig(proto.Message):
 
 class DefaultPool(proto.Message):
     r"""Execution using the default Cloud Build pool.
+
     Attributes:
         service_account (str):
             Optional. Google service account to use for execution. If
@@ -568,6 +576,7 @@ class DefaultPool(proto.Message):
 
 class PrivatePool(proto.Message):
     r"""Execution using a private Cloud Build pool.
+
     Attributes:
         worker_pool (str):
             Required. Resource name of the Cloud Build worker pool to
@@ -594,6 +603,7 @@ class PrivatePool(proto.Message):
 
 class GkeCluster(proto.Message):
     r"""Information specifying a GKE Cluster.
+
     Attributes:
         cluster (str):
             Information specifying a GKE Cluster. Format is
@@ -605,6 +615,7 @@ class GkeCluster(proto.Message):
 
 class ListTargetsRequest(proto.Message):
     r"""The request object for ``ListTargets``.
+
     Attributes:
         parent (str):
             Required. The parent, which owns this collection of targets.
@@ -641,6 +652,7 @@ class ListTargetsRequest(proto.Message):
 
 class ListTargetsResponse(proto.Message):
     r"""The response object from ``ListTargets``.
+
     Attributes:
         targets (Sequence[google.cloud.deploy_v1.types.Target]):
             The ``Target`` objects.
@@ -663,6 +675,7 @@ class ListTargetsResponse(proto.Message):
 
 class GetTargetRequest(proto.Message):
     r"""The request object for ``GetTarget``.
+
     Attributes:
         name (str):
             Required. Name of the ``Target``. Format must be
@@ -674,6 +687,7 @@ class GetTargetRequest(proto.Message):
 
 class CreateTargetRequest(proto.Message):
     r"""The request object for ``CreateTarget``.
+
     Attributes:
         parent (str):
             Required. The parent collection in which the ``Target``
@@ -716,6 +730,7 @@ class CreateTargetRequest(proto.Message):
 
 class UpdateTargetRequest(proto.Message):
     r"""The request object for ``UpdateTarget``.
+
     Attributes:
         update_mask (google.protobuf.field_mask_pb2.FieldMask):
             Required. Field mask is used to specify the fields to be
@@ -764,6 +779,7 @@ class UpdateTargetRequest(proto.Message):
 
 class DeleteTargetRequest(proto.Message):
     r"""The request object for ``DeleteTarget``.
+
     Attributes:
         name (str):
             Required. The name of the ``Target`` to delete. Format
@@ -896,6 +912,7 @@ class Release(proto.Message):
 
     class TargetRender(proto.Message):
         r"""Details of rendering for a single target.
+
         Attributes:
             rendering_build (str):
                 Output only. The resource name of the Cloud Build ``Build``
@@ -953,6 +970,7 @@ class Release(proto.Message):
 
 class BuildArtifact(proto.Message):
     r"""Description of an a image to use during Skaffold rendering.
+
     Attributes:
         image (str):
             Image name in Skaffold configuration.
@@ -969,6 +987,7 @@ class BuildArtifact(proto.Message):
 
 class TargetArtifact(proto.Message):
     r"""The artifacts produced by a target render operation.
+
     Attributes:
         artifact_uri (str):
             Output only. URI of a directory containing
@@ -990,6 +1009,7 @@ class TargetArtifact(proto.Message):
 
 class ListReleasesRequest(proto.Message):
     r"""The request object for ``ListReleases``.
+
     Attributes:
         parent (str):
             Required. The ``DeliveryPipeline`` which owns this
@@ -1025,6 +1045,7 @@ class ListReleasesRequest(proto.Message):
 
 class ListReleasesResponse(proto.Message):
     r"""The response object from ``ListReleases``.
+
     Attributes:
         releases (Sequence[google.cloud.deploy_v1.types.Release]):
             The ``Release`` objects.
@@ -1047,6 +1068,7 @@ class ListReleasesResponse(proto.Message):
 
 class GetReleaseRequest(proto.Message):
     r"""The request object for ``GetRelease``.
+
     Attributes:
         name (str):
             Required. Name of the ``Release``. Format must be
@@ -1058,6 +1080,7 @@ class GetReleaseRequest(proto.Message):
 
 class CreateReleaseRequest(proto.Message):
     r"""The request object for ``CreateRelease``,
+
     Attributes:
         parent (str):
             Required. The parent collection in which the ``Release``
@@ -1209,6 +1232,7 @@ class Rollout(proto.Message):
 
 class ListRolloutsRequest(proto.Message):
     r"""ListRolloutsRequest is the request object used by ``ListRollouts``.
+
     Attributes:
         parent (str):
             Required. The ``Release`` which owns this collection of
@@ -1268,6 +1292,7 @@ class ListRolloutsResponse(proto.Message):
 
 class GetRolloutRequest(proto.Message):
     r"""GetRolloutRequest is the request object used by ``GetRollout``.
+
     Attributes:
         name (str):
             Required. Name of the ``Rollout``. Format must be
@@ -1323,6 +1348,7 @@ class CreateRolloutRequest(proto.Message):
 
 class OperationMetadata(proto.Message):
     r"""Represents the metadata of the long-running operation.
+
     Attributes:
         create_time (google.protobuf.timestamp_pb2.Timestamp):
             Output only. The time the operation was
@@ -1361,6 +1387,7 @@ class OperationMetadata(proto.Message):
 
 class ApproveRolloutRequest(proto.Message):
     r"""The request object used by ``ApproveRollout``.
+
     Attributes:
         name (str):
             Required. Name of the Rollout. Format is
@@ -1375,11 +1402,13 @@ class ApproveRolloutRequest(proto.Message):
 
 
 class ApproveRolloutResponse(proto.Message):
-    r"""The response object from ``ApproveRollout``.    """
+    r"""The response object from ``ApproveRollout``.
+    """
 
 
 class Config(proto.Message):
     r"""Service-wide configuration.
+
     Attributes:
         name (str):
             Name of the configuration.
@@ -1401,6 +1430,7 @@ class Config(proto.Message):
 
 class SkaffoldVersion(proto.Message):
     r"""Details of a supported Skaffold version.
+
     Attributes:
         version (str):
             Release version number. For example,
@@ -1416,6 +1446,7 @@ class SkaffoldVersion(proto.Message):
 
 class GetConfigRequest(proto.Message):
     r"""Request to get a configuration.
+
     Attributes:
         name (str):
             Required. Name of requested configuration.
